Boring Math - Special Functions
===============================

PyPI project
`boring-math-special-functions
<https://pypi.org/project/boring-math-special-functions>`_.

The purpose of this project is to compute special functions
of mathematics and Physics.

Initially these will be done in pure Python, but eventually I
would like to implement these in something like C, Zig or Rust.

This pypi project is part of the
`boring math
<https://grscheller.github.io/boring-math>`_ projects.

Documentation
-------------

Documentation for this project is hosted on
`GitHub Pages
<https://grscheller.github.io/boring-math/special-functions>`_.

Copyright and License
---------------------

Copyright (c) 2023-2026 Geoffrey R. Scheller. Licensed under the Apache
License, Version 2.0. See the LICENSE file for details.
